#
# spec file for package libmpdclient
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2
Name:           libmpdclient
Version:        2.23
Release:        1.1
Summary:        Library for interfacing the Music Player Daemon
License:        BSD-2-Clause AND BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://musicpd.org/libs/%{name}
Source0:        https://musicpd.org/download/%{name}/%{sover}/%{name}-%{version}.tar.xz
Source1:        https://musicpd.org/download/%{name}/%{sover}/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
Source3:        doxygen-nodatetime-footer.html
Patch0:         %{name}-doxygen_nodatetime.patch
BuildRequires:  check-devel
BuildRequires:  doxygen
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig

%description
A stable, documented, asynchronous API library for interfacing MPD (Music Player Daemon)
in the C, C++ & Objective C languages.

%package -n %{name}%{sover}
Summary:        Library for interfacing the Music Player Daemon
Group:          System/Libraries

%description -n %{name}%{sover}
A stable, documented, asynchronous API library for interfacing MPD (Music Player Daemon).

%package devel
Summary:        Development files for libmpdclient
Group:          Development/Languages/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
This package contains the development files, e.g. header-files, for
libmpdclient - a stable, documented and asynchronous API library for
MPD (Music Player Daemon).

%prep
%autosetup -p1

%build
%meson -Ddocumentation=true -Dtest=true
cp %{SOURCE3} %{_vpath_builddir}/doc
%meson_build

%install
%meson_install
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/doc/%{name}/* %{buildroot}%{_docdir}/%{name}

%check
%meson_test

%ldconfig_scriptlets -n %{name}%{sover}

%files -n %{name}%{sover}
%license LICENSES/BSD-2-Clause.txt LICENSES/BSD-3-Clause.txt
%doc AUTHORS
%{_libdir}/%{name}.so.*

%files devel
%doc %{_docdir}/%{name}
%{_includedir}/mpd
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Fri Jul  4 2025 Илья Индиго <ilya@ilya.top>
- Added libmpdclient-2.23.tar.xz.sig and libmpdclient.keyring.
- Changed libmpdclient-doxygen_nodatetime.patch.
- Updated to 2.23
  * https://raw.githubusercontent.com/MusicPlayerDaemon/libmpdclient/v2.23/NEWS
  * Supported MPD protocol 0.24.0
  * allow window for listplaylist and listplaylistinfo
  * command "playlistlength", "protocol", "stickertypes", "stickernamestypes",
    "searchplaylist", tag "ShowMovement"
  * new sticker find api
  * new subcommands for "tagtypes": "available", "reset"
  * supported open end for mpd_search_add_window
  * format floating-point numbers with the POSIX localew
* Tue Apr 16 2024 Илья Индиго <13ilya@gmail.com>
- Updated to 2.22
  * https://raw.githubusercontent.com/MusicPlayerDaemon/libmpdclient/v2.22/NEWS
  * Changed license to BSD-2-Clause AND BSD-3-Clause.
  * Removed the unmaintained Vala bindings.
  * Added mpd_recv_replay_gain_status()
  * Added support MPD protocol 0.24.0:
  * tag "Mood", "TitleSort"
  * "oneshot" consume state
  * allow range in "playlistmove"
  * commands "searchcount", "stickernames"
  * added attribute for songs
  * search: support constraint "added-since"
  * command "save [create|replace|append]"
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Nov 29 2021 Илья Индиго <ilya@ilya.pp.ua>
- Updated to 2.20
  * https://raw.githubusercontent.com/MusicPlayerDaemon/libmpdclient/v2.20/NEWS
  * support MPD protocol 0.23:
  * getvol
  * position argument for searchadd, findadd, load and playlistadd
  * whence argument for addid and add
  * range argument for playlistdelete
  * support MPD protocol 0.22.4: binarylimit
  * support MPD protocol 0.22.0: readpicture
  * support MPD protocol 0.21.0: albumart
  * support tags: "ComposerSort", "Ensemble", "Movement", "MovementNumber", "Location"
  * queue: make "priority" parameter unsigned
* Mon Dec 14 2020 Tejas Guruswamy <tejas.guruswamy@opensuse.org>
- Add patch libmpdclient-doxygen_nodatetime.patch.
- Add file doxygen-nodatetime-footer.html.
- Include documentation and place vala files in properly versioned
  subdirectory in devel package.
* Fri Jul  3 2020 Илья Индиго <ilya@ilya.pp.ua>
- Update to 2.19
  * https://raw.githubusercontent.com/MusicPlayerDaemon/libmpdclient/v2.19/NEWS
  * fix off-by-one bug in MPD_HOST parser
  * add function mpd_lookup_replay_gain_mode()
  * identify messages with length over the buffer limit
  * support MPD protocol 0.16: replay gain
  * support MPD protocol 0.19: idle events "neighbor" and "mount"
  * support MPD protocol 0.20: rangeid
  * support MPD protocol 0.21: command "tagtypes all"
* Mon Jan 27 2020 Илья Индиго <ilya@ilya.pp.ua>
- Update to 2.18
  * https://raw.githubusercontent.com/MusicPlayerDaemon/libmpdclient/v2.18/NEWS
  * more out-of-memory checks
  * partition: add mpd_recv_partition()
  * support MPD protocol 0.21
  * "oneshot" single state
  * support MPD protocol 0.22
  * status: add mpd_status_get_partition()
  * commands "delpartition", "moveoutput"
* Thu Dec  5 2019 Илья Индиго <ilya@ilya.pp.ua>
- Update to 2.17
  * https://raw.githubusercontent.com/MusicPlayerDaemon/libmpdclient/v2.17/NEWS
  * search: add mpd_search_add_db_songs_to_playlist()
  * idle: support event "partition"
  * support MPD protocol 0.19 - "listneighbors"
  * support MPD protocol 0.22 - "getfingerprint"
  * support tags "MPD_TAG_LABEL", "MPD_TAG_MUSICBRAINZ_WORKID",
    "Grouping", "Work", "Conductor"
  * support MPD partitions
  * mpd_async_set_keepalive() returns bool
  * mpd_connection_set_keepalive() returns bool
* Thu Nov  8 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.16
  * support MPD protocol 0.19
    + "mount", "unmount", "listmounts"
  * support MPD protocol 0.17
    + "load" with range
  * add mpd_output_get_attribute()
  * use UINX_MAX instead of `(unsigned)-1` to avoid undefined
    behavior
* Thu Oct  4 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.15:
  * support MPD protocol 0.17
  * Various compiler warning fixes
- Use meson macros
* Sat May  5 2018 tejas.guruswamy@opensuse.org
- Update to 2.14
  * support MPD protocol 0.21
  - command "outputset"
  - mpd_output_get_plugin()
  - receive output attributes
  * MSVC compatibility
  * improved local and abstract socket support
* Thu Jul 27 2017 olaf@aepfle.de
- Update to 2.13
  * fix build with meson > 0.38.1
  * fix connect error "Operation now in progress"
  * support MPD protocol 0.21
  - support tag "OriginalDate"
  - command "tagtypes" plus "disable", "enable", "clear"
  * support MPD protocol 0.20
  - support "plchanges" and "plchangesposid" with range
  * support MPD protocol 0.19
  - commands "addtagid", "cleartagid"
  - command "listfiles"
  - grouping for "list" and "count"
  - tag "AlbumSort"
  - "seekid" with float time
  * use relative #include paths to avoid clashes with other libmpdclient copies
  * build with Meson instead of autotools
* Mon Apr 17 2017 olaf@aepfle.de
- Update to 2.11
  * fix heap corruption with mpd_connection_new_async()
  * add space before "window" search argument
  * detect getaddrinfo() at configure time
  * add support for ArtistSort and AlbumArtistSort tags
  * support MPD protocol 0.21
  - audio format specifications "dsd64" etc.
* Sun Nov  1 2015 rpm@fthiessen.de
- Updated package to 2.10
  * support abstract sockets with "@" prefix
  * support tag "MUSICBRAINZ_RELEASETRACKID"
  * add TCP keepalive internal and external APIs
  * support MPD protocol 0.19 and 0.20
* Sat Oct 31 2015 rpm@fthiessen.de
- Initial version 2.9
